<?php
/**
 * iCare functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package iCare
 */
if (!function_exists('icare_setup')):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */

    function icare_setup()
{

        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on iCare, use a find and replace
         * to change 'icare' to the name of your theme in all the template files.
         */
        load_theme_textdomain('icare', get_template_directory() . '/languages');
        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');
        //custom logo
        add_theme_support('custom-logo', array(
            'height'      => 50,
            'width'       => 150,
            'flex-width'  => true,
            'flex-height' => false,
            'header-text' => array('site-title', 'site-description'),
        ));
        add_editor_style(get_stylesheet_directory_uri() . '/assets/css/icare-editor-style.css');
        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');
        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');
        add_theme_support('woocommerce');
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');
        add_theme_support('wc-product-gallery-slider');
        add_image_size('icare_home_slider', 1440, 550, true);
        add_image_size('icare_blog_classic_img', 900, 450, true);
        add_image_size('icare_home_doc_profile', 363, 247, true);
        add_image_size('icare_home_blog_thumb', 360, 220, true);
        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary-menu' => esc_html__('Primary Menu', 'icare'),
            'topbar-menu'  => esc_html__('Top bar Menu', 'icare'),
            'footer-menu'  => esc_html__('Footer Menu', 'icare'),
        ));
        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));
        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('icare_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));
        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');
        add_theme_support('starter-content', array(

            'posts'     => array(
                'home'    => array(
                    'template' => 'home-page.php',
                ),
                'about'   => array(
                    'thumbnail' => '{{image-sandwich}}',
                ),
                'contact' => array(
                    'thumbnail' => '{{image-espresso}}',
                ),
                'blog'    => array(
                    'thumbnail' => '{{image-coffee}}',
                ),
            ),

            'options'   => array(
				'icare_show_topbar'  => 1,
				'icare_footer_social_or_menu' => 'simple-links',
				'icare_topbar_social_or_menu' => 'social-links',
                'show_on_front'  => 'page',
                'page_on_front'  => '{{home}}',
                'page_for_posts' => '{{blog}}',
            ),
            'widgets'   => array(
                'icare-topbar-widget' => array(
                    'text_cta_contact' => array(
                        'text', array(
                            'title' => '', // Blank title
                            'text'  => sprintf('<div class="widget no-border m-five text-white">
                  <i class="fa fa-clock-o text-theme-colored"></i>%s</div>',__('Opening Hours:  Mon - Tues : 6.00 am - 10.00 pm, Sunday Closed','icare')),
                        ),
                    ),
                ),
                'icare-home-service' => array(
                    'icare_home_service-1' => array(
                        'text', array(
                            'title' => __('Lorem ipsum','icare'), // Blank title
                            'text'  => sprintf(__('Lorem ipsum dolor sit amet, consectetur adipisicing elit. Molestias non null','icare')),
                        ),
                    ),
                    'icare_home_service-2' => array(
                        'text', array(
                            'title' => __('Lorem ipsum','icare'), // Blank title
                            'text'  => sprintf(__('Lorem ipsum dolor sit amet, consectetur adipisicing elit. Molestias non null','icare')),
                        ),
                    ),
                    'icare_home_service-3' => array(
                        'text', array(
                            'title' => __('Lorem ipsum','icare'), // Blank title
                            'text'  => sprintf(__('Lorem ipsum dolor sit amet, consectetur adipisicing elit. Molestias non null','icare')),
                        ),
                    ),
                ),
                'sidebar-r'             => array(
                    'search',
                    'text_business_info',
                    'text_about',
                    'category',
                    'tags',
                ),

                'footer-1'              => array(
                    'text_business_info',
                    'text_about',
                    'meta',
                    'search',
                ),
            ),

            'nav_menus' => array(
                'primary-menu' => array(
                    'name'  => __('Primary Menu', 'icare'),
                    'items' => array(
                        'page_home',
                        'page_about',
                        'page_blog',
                        'page_contact',
                    ),
                ),
                'topbar-menu'  => array(
                    'name'  => __('Top Menu', 'icare'),
                    'items' => array(
                        'link_yelp',
                        'link_facebook',
                        'link_twitter',
                        'link_instagram',
                        'link_email',
                    ),
                ),
                'footer-menu'  => array(
                    'name'  => __('Footer Menu', 'icare'),
                    'items' => array(
                        'page_home',
                        'page_about',
                        'page_blog',
                        'page_contact',
                    ),
                ),
            ),
        ));
    }
endif;
add_action('after_setup_theme', 'icare_setup');
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function icare_content_width()
{
    $GLOBALS['content_width'] = apply_filters('icare_content_width', 1440);
}
add_action('after_setup_theme', 'icare_content_width', 0);
/**
 * Register icare-widget.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function icare_widgets_init()
{
    register_sidebar(array(
        'name'          => esc_html__('Right Sidebar', 'icare'),
        'id'            => 'sidebar-r',
        'description'   => esc_html__('Add widgets here.', 'icare'),
        'before_widget' => '<widget id="%1$s" class="icare-widget no-border m-zero %2$s">',
        'after_widget'  => '</widget>',
        'before_title'  => '<h5 class="icare-widget-title widget-title-border-bottom">',
        'after_title'   => '</h5>',
    ));
    register_sidebar(array(
        'name'          => esc_html__('Top bar Widget area', 'icare'),
        'id'            => 'icare-topbar-widget',
        'description'   => esc_html__('Add Text widget here.', 'icare'),
        'before_widget' => '<div id="%1$s" class="icare-widget text-white no-border m-zero %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="icare-widget-title widget-title-border-bottom text-white">',
        'after_title'   => '</h5>',
    ));
  

    register_sidebar(array(
        'name'          => esc_html__('Home Service Widget Area', 'icare'),
        'id'            => 'icare-home-service',
        'description'   => esc_html__('Add Text widgets here.', 'icare'),
        'before_widget' => '<div class="col-xs-12 col-sm-6 col-md-4 equal-height"><div id="%1$s" class="icare-icon-box p-twenty mb-thirty border-1pt %2$s">',
        'after_widget'  => '</div></div>',
        'before_title'  => '<h5 class="class="icare-icon-box-title m-zero mb-five">',
        'after_title'   => '</h5>',
    ));

    $col = get_theme_mod('icare_footer_widget_column');
    $col = $col != "" ? $col : 3;
    register_sidebar(array(
        'name'          => esc_html__('Footer Widget Area', 'icare'),
        'id'            => 'footer-1',
        'description'   => esc_html__('Add widgets here.', 'icare'),
        'before_widget' => '<div class="col-sm-6 col-md-' . $col . '">
								<div id="%1$s" class="icare-widget dark %2$s">',
        'after_widget'  => '</div></div>',
        'before_title'  => '<h5 class="icare-widget-title widget-title-border-bottom">',
        'after_title'   => '</h5>',
    ));
}
add_action('widgets_init', 'icare_widgets_init');
/**
 * Enqueue scripts and styles.
 */
function icare_scripts()
{
    wp_enqueue_style('bootstrap', get_template_directory_uri() . "/assets/css/bootstrap.css");
    wp_enqueue_style('animate', get_template_directory_uri() . "/assets/css/animate.css");
    wp_enqueue_style('icare-css-plugin-collections', get_template_directory_uri() . "/assets/css/icare-css-plugin-collections.css");

    // fontawesome-icons
    wp_enqueue_style('font-awesome', get_template_directory_uri() . "/assets/css/font-awesome.css");
    // CSS | Main style file
    wp_enqueue_style('icare-style', get_stylesheet_uri());
    
    // CSS | Custom Margin Padding Collection
    wp_enqueue_style('icare-custom-margin-padding', get_template_directory_uri() . "/assets/css/icare-custom-margin-padding.css");

    // CSS | Theme Color
    wp_enqueue_style('icare-theme-skin-sky-blue', get_template_directory_uri() . "/assets/css/colors/theme-skin-sky-blue.css");
    //fonts
    wp_enqueue_style('icare-fonts', '//fonts.googleapis.com/css?family=Open+Sans:300,400,500,600,700,800|Raleway:400,300,200,500,700,600,800|Playfair+Display:400,400italic,700,700italic|Montserrat:400,700');
    wp_enqueue_script('jquery');
    // external javascripts
    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js');
    // JS | jquery plugin collection for this theme
    wp_enqueue_script('icare-jquery-plugin-collection', get_template_directory_uri() . '/assets/js/icare-js-plugin-collection.js');
    wp_enqueue_script('icare-custom', get_template_directory_uri() . '/assets/js/icare-custom.js', array(), '20170301', true);
    wp_enqueue_script('icare-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true);
    wp_localize_script('icare-custom', 'brand', array(
        'logo' => icare_site_title_or_logo(false),
    ));
    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'icare_scripts');
/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/class-icare-customizer.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';
/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';
/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';
/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
/**
 * Metabox.
 */
require get_template_directory() . '/functions/metabox.php';
/**
 * Load Menu walker.
 */
/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path('/inc/icon-functions.php');

require get_template_directory() . '/functions/menu/icare_default_menu_walker.php';
require get_template_directory() . '/functions/menu/icare_nav_walker.php';
require 'inc/icare-template-hooks.php';
require 'inc/icare-template-functions.php';
