<?php
/**
 * iCare Premium Theme Customizer.
 *
 * @package iCare Premium
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists('iCare_Customizer')):

    /**
     * The icare Customizer class
     */
    class iCare_Customizer
{
        public static $theme_slug = 'icare_';
        /**
         * Setup class.
         *
         * @since 1.0
         */
        public function __construct()
    {
            add_action('customize_register', array($this, 'icare_customize_register1'), 10);
            add_action('wp_enqueue_scripts', array($this, 'icare_add_customizer_css'), 130);
            //add_action( 'after_setup_theme',               array( $this, 'custom_header_setup' ) );
            add_action('customize_controls_print_styles', array($this, 'icare_customizer_custom_control_css'));
            add_action('customize_register', array($this, 'icare_edit_default_customizer_settings'), 99);
            add_action('init', array($this, 'icare_default_theme_mod_values'), 10);

            add_action('after_switch_theme', array($this, 'icare_set_style_theme_mods'));
            add_action('customize_save_after', array($this, 'icare_set_style_theme_mods'));
        }
        /**
         * Returns an array of the desired default iCare Options
         *
         * @return array
         */
        public static function icare_get_default_setting_values()
    {
            $default = json_encode(array("home-service", "home-about_1", "home-about_2", "home-posts", "home-calltoaction"));
            return apply_filters('icare_setting_default_values', $args = array(
                self::$theme_slug . 'show_topbar'                => 0,
                self::$theme_slug . 'home_reorder'               => $default,
                self::$theme_slug . 'topbar_bg_color'            => '#00A4EF',
                self::$theme_slug . 'topbar_social_or_menu'      => '',
                self::$theme_slug . 'home_blog_color'            => '#ffffff',
                self::$theme_slug . 'home_blog_title'            => esc_html__('Latest Posts', 'icare'),
                self::$theme_slug . 'show_cta'                   => 1,
                self::$theme_slug . 'cta_bg_color'               => '#00A4EF',
                self::$theme_slug . 'cta_font_color'             => '#FFFFFF',
                self::$theme_slug . 'calltoaction_title'         => esc_html__('Need Help? Call Us. +91-8899859898', 'icare'),
                self::$theme_slug . 'calltoaction_btn1_text'     => esc_html__('Purchase Now', 'icare'),
                self::$theme_slug . 'calltoaction_btn1_url'      => '#',
                self::$theme_slug . 'calltoaction_btn2_text'     => esc_html__('Learn More', 'icare'),
                self::$theme_slug . 'calltoaction_btn2_url'      => '#',
                self::$theme_slug . 'fixed_header'               => 0,
                self::$theme_slug . 'header_background_color'    => '#ffffff',
                self::$theme_slug . 'menu_color'                 => '#333333',
                self::$theme_slug . 'menu_color_hover'           => '#ffffff',
                self::$theme_slug . 'menu_bg_color'              => '#5D9CEC',
                self::$theme_slug . 'crumb_and_title'            => 'allow_both',
                self::$theme_slug . 'crumb_title_align'          => 'left',
                self::$theme_slug . 'br_s_p_t'                   => 60,
                self::$theme_slug . 'br_s_p_b'                   => 60,
                self::$theme_slug . 'breadcrumbs_font_color'     => '#333333',
                self::$theme_slug . 'show_hero'                  => 1,
                self::$theme_slug . 'hero_image'                 => get_template_directory_uri() . '/assets/images/icare-nurse-2141808_1280.jpg',
                self::$theme_slug . 'hero_title'                 => esc_html__('Need Consultant?', 'icare'),
                self::$theme_slug . 'hero_desc'                  => esc_html__('Make an appointment', 'icare'),
                self::$theme_slug . 'show_services'              => 1,
                self::$theme_slug . 'service_head'               => esc_html__('Our Services', 'icare'),
                self::$theme_slug . 'service_color'              => '#ffffff',
                self::$theme_slug . 'show_aboutus1'              => 0,
                self::$theme_slug . 'about_color1'               => '#eee',
                self::$theme_slug . 'about_head1'                => esc_html__('About Us', 'icare'),
                self::$theme_slug . 'about_desc1'                => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisicing elit', 'icare'),
                self::$theme_slug . 'show_aboutus2'              => 0,
                self::$theme_slug . 'about_color2'               => '#eee',
                self::$theme_slug . 'about_head2'                => esc_html__('Meet Our Team', 'icare'),
                self::$theme_slug . 'about_desc2'                => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisicing elit', 'icare'),
                self::$theme_slug . 'show_footer_widget'         => 1,
                self::$theme_slug . 'footer_widget_column'       => 3,
                self::$theme_slug . 'footer_social_or_menu'      => '',
                self::$theme_slug . 'footer_background_color'    => '#222222',
                self::$theme_slug . 'footer_heading_color'       => '#ffffff',
                self::$theme_slug . 'footer_text_color'          => '#808080',
                self::$theme_slug . 'footer_link_color'          => '#00A4EF',
                self::$theme_slug . 'footer_copyright_text'      => esc_html__('iCare Theme Developed By | ', 'icare'),
                self::$theme_slug . 'footer_copyright_link_text' => esc_html__('WebHunt Infotech', 'icare'),
                self::$theme_slug . 'footer_copyright_link'      => 'https://www.webhuntinfotech.com',
            ));
        }

        /**
         * Adds a value to each Shopify setting if one isn't already present.
         *
         * @uses icare_get_default_setting_values()
         */
        public function icare_default_theme_mod_values()
    {
            foreach (self::icare_get_default_setting_values() as $mod => $val) {
                add_filter('theme_mod_' . $mod, array($this, 'icare_get_theme_mod_value'), 10);
            }
        }

        /**
         * Get theme mod value.
         *
         * @param string $value
         * @return string
         */
        public function icare_get_theme_mod_value($value)
    {
            $key = substr(current_filter(), 10);

            $set_theme_mods = get_theme_mods();
            if (isset($set_theme_mods[$key])) {
                return $value;
            }

            $values = $this->icare_get_default_setting_values();

            return isset($values[$key]) ? $values[$key] : $value;
        }

        /**
         * Set Customizer setting defaults.
         * These defaults need to be applied separately as child themes can filter shopify_setting_default_values
         *
         * @param  array $wp_customize the Customizer object.
         * @uses   icare_get_default_setting_values()
         */
        public function icare_edit_default_customizer_settings($wp_customize)
    {
            foreach (self::icare_get_default_setting_values() as $mod => $val) {
                $wp_customize->get_setting($mod)->default = $val;
            }
        }

        /**
         * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
         *
         * @param WP_Customize_Manager $wp_customize Theme Customizer object.
         * @since  1.0.0
         */
        public function icare_customize_register1($wp_customize)
    {
            /**
             * Custom controls
             */
            require_once dirname(__FILE__) . '/class-icare-customizer-control-radio-image.php';
            require_once dirname(__FILE__) . '/class-icare-customizer-control-arbitrary.php';
            $categories = get_categories();
            $cats       = array();
            foreach ($categories as $category) {
                $cats[$category->term_id] = $category->name;
            }
            //Add Panel
            $theme_slug = self::$theme_slug;

            $wp_customize->add_panel(
                $theme_slug . 'footer',
                array(
                    'capability'  => 'edit_theme_options',
                    'title'       => esc_html__('Footer Options', 'icare'),
                    'description' => esc_html__('configure Footer background color, footer copyright info, footer social media icons etc', 'icare'),
                    'priority'    => 31,
                )
            );
            $wp_customize->add_panel(
                $theme_slug . 'service',
                array(
                    'capability'  => 'edit_theme_options',
                    'title'       => esc_html__('Service Options', 'icare'),
                    'description' => esc_html__('Add & configure Home Services', 'icare'),
                    'priority'    => 26,
                )
            );

            $section_controls = array(
                'topbar_contact'        => array(
                    'title'       => esc_html__('Topbar Options', 'icare'),
                    'description' => esc_html__('Show Contact Information in topbar', 'icare'),
                    'priority'    => 24,
                    'fields'      => array(
                        'show_topbar'           => array(
                            'title'       => esc_html__('Show Topbar', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',

                        ),
                        //topbar color optiond
                        'topbar_bg_color'       => array(
                            'title'       => esc_html__('Topbar Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),

                        // topbar social icon or menu
                        'topbar_social_or_menu' => array(
                            'title'       => esc_html__('Show social Media Links or a Simple Menu', 'icare'),
                            'description' => __('These menu can be set in the <a class="linkToControl" id="nav_menu_locations[topbar-menu]" href="#">Menu Section</a>.', 'icare'),
                            'field_type'  => 'select',
                            'sanitize'    => 'sanitize_text_field',
                            'choices'     => array(
                                'social-links' => esc_html__('Social Links Menu', 'icare'),
                                'simple-links' => esc_html__('Simple Menu', 'icare'),
                                ''             => esc_html__('Blank', 'icare'),
                            ),
                        ),

                    ),
                ),
                'slider'                => array(
                    'title'       => esc_html__('Hero Section', 'icare'),
                    'description' => '',
                    'priority'    => 25,
                    'fields'      => array(
                        'show_hero'        => array(
                            'title'       => esc_html__('Show Hero Section', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',

                        ),
                        'hero_image'       => array(
                            'title'       => esc_html__('Hero Image', 'icare'),
                            'description' => '',
                            'field_type'  => 'image',
                            'sanitize'    => 'esc_url_raw',

                        ),
                        'hero_title'       => array(
                            'title'       => esc_html__('Hero Title', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                            'transport'   => 'postMessage',

                        ),
                        'hero_desc'        => array(
                            'title'       => esc_html__('Hero Description', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                            'transport'   => 'postMessage',

                        ),
                        'slider_shortcode' => array(
                            'title'       => esc_html__('Or put slider shortcode here', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                        ),
                    ),
                ),
                //services
                'services'              => array(
                    'title'       => esc_html__('Service Title & BG color', 'icare'),
                    'description' => '',
                    'panel'       => 'service',
                    'priority'    => 10,
                    'fields'      => array(
                        'show_services' => array(
                            'title'       => esc_html__('Show Service Section', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',

                        ),
                        'service_color' => array(
                            'title'       => esc_html__('Service Section Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                            'transport'   => 'postMessage',

                        ),
                        'service_head'  => array(
                            'title'       => esc_html__('Service Heading', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                    ),
                ),
                // home extra 1
                'home_about1'           => array(
                    'title'       => esc_html__('Home Extra Section 1', 'icare'),
                    'description' => '',
                    'priority'    => 27,
                    'fields'      => array(
                        'show_aboutus1'     => array(
                            'title'       => esc_html__('Enable this Section', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',

                        ),
                        'about_color1'      => array(
                            'title'       => esc_html__('Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',

                        ),
                        'about_head1'       => array(
                            'title'       => esc_html__('Heading', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                        'about_head1_color' => array(
                            'title'       => esc_html__('Heading Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',

                        ),
                        'about_desc1'       => array(
                            'title'       => esc_html__('Description', 'icare'),
                            'description' => '',
                            'field_type'  => 'textarea',
                            'sanitize'    => 'sanitize_text_fieldarea',
                            'transport'   => 'postMessage',
                        ),
                        'about_desc1_color' => array(
                            'title'       => esc_html__('Description Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',

                        ),
                        'home_about1'       => array(
                            'title'          => esc_html__('Select Page.', 'icare'),
                            'description'    => '',
                            'field_type'     => 'dropdown-pages',
                            'allow_addition' => true,
                            'sanitize'       => 'absint',
                        ),
                    ),
                ),
                // home extra 2
                'home_about2'           => array(
                    'title'       => esc_html__('Home Extra Section 2', 'icare'),
                    'description' => '',
                    'priority'    => 27,
                    'fields'      => array(
                        'show_aboutus2' => array(
                            'title'       => esc_html__('Enable this Section', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',

                        ),
                        'about_color2'  => array(
                            'title'       => esc_html__('Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',

                        ),
                        'about_head2'   => array(
                            'title'       => esc_html__('Heading', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                        'about_desc2'   => array(
                            'title'       => esc_html__('Description', 'icare'),
                            'description' => '',
                            'field_type'  => 'textarea',
                            'sanitize'    => 'sanitize_text_fieldarea',
                            'transport'   => 'postMessage',
                        ),
                        'home_about2'   => array(
                            'title'          => esc_html__('Select Page.', 'icare'),
                            'description'    => '',
                            'field_type'     => 'dropdown-pages',
                            'allow_addition' => true,
                            'sanitize'       => 'absint',
                        ),
                    ),
                ),
                'home_blog'             => array(
                    'title'       => esc_html__('Home Blog', 'icare'),
                    'description' => '',
                    'priority'    => 29,
                    'fields'      => array(
                        //home blog
                        'home_blog_color' => array(
                            'title'       => esc_html__('Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                            'transport'   => 'postMessage',
                        ),
                        'home_blog_title' => array(
                            'title'       => esc_html__('Title', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                    ),
                ),
                'calltoaction'          => array(
                    'title'       => esc_html__('Call To Action', 'icare'),
                    'description' => '',
                    'priority'    => 30,
                    'fields'      => array(
                        //calltoaction
                        'show_cta'               => array(
                            'title'       => esc_html__('Show CallToAction section', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',
                        ),
                        'cta_bg_color'           => array(
                            'title'       => esc_html__('Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'cta_font_color'         => array(
                            'title'       => esc_html__('Font Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'calltoaction_title'     => array(
                            'title'       => esc_html__('Title', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                        'calltoaction_btn1_url'  => array(
                            'title'       => esc_html__('Button 1 URL', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'esc_url',
                            'transport'   => 'postMessage',
                        ),
                        'calltoaction_btn1_text' => array(
                            'title'       => esc_html__('Button 1 Text', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),

                        'calltoaction_btn2_url'  => array(
                            'title'       => esc_html__('Button 2 URL', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'esc_url',
                            'transport'   => 'postMessage',
                        ),
                        'calltoaction_btn2_text' => array(
                            'title'       => esc_html__('Button 2 Text', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                    ),
                ),
                'footer_widget'         => array(
                    'title'       => esc_html__('Footer Widget', 'icare'),
                    'description' => esc_html__('Show/ Hide footer widgets and change footer widget columns', 'icare'),
                    'panel'       => 'footer',
                    'priority'    => 25,
                    'fields'      => array(
                        //Footer Color options
                        'show_footer_widget'   => array(
                            'title'       => esc_html__('Show Footer Widgets', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',

                        ),
                        'footer_widget_column' => array(
                            'title'       => esc_html__('Footer Widget Column', 'icare'),
                            'description' => '',
                            'field_type'  => 'radio-image',
                            'sanitize'    => 'absint',
                            'choices'     => array(
                                6 => esc_url(get_template_directory_uri() . '/assets/images/layout/icare-footer-widgets-2.png'),
                                4 => esc_url(get_template_directory_uri() . '/assets/images/layout/icare-footer-widgets-3.png'),
                                3 => esc_url(get_template_directory_uri() . '/assets/images/layout/icare-footer-widgets-4.png'),
                            ),
                        ),
                    ),
                ),
                'footer_color'          => array(
                    'title'       => esc_html__('Color Options', 'icare'),
                    'description' => '',
                    'panel'       => 'footer',
                    'priority'    => 25,
                    'fields'      => array(
                        //Footer Color options
                        'footer_background_color' => array(
                            'title'       => esc_html__('Footer Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',

                        ),
                        'footer_heading_color'    => array(
                            'title'       => esc_html__('Footer Heading Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'footer_text_color'       => array(
                            'title'       => esc_html__('Footer Text Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'footer_link_color'       => array(
                            'title'       => esc_html__('Footer Link Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                    ),
                ),
                'footer_copyright_text' => array(
                    'title'       => esc_html__('Copyright Text', 'icare'),
                    'description' => '',
                    'priority'    => 25,
                    'panel'       => 'footer',
                    'fields'      => array(
                        //footer copyright options
                        'footer_copyright_text'      => array(
                            'title'       => esc_html__('Footer Copyright Text', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                        'footer_copyright_link_text' => array(
                            'title'       => esc_html__('Footer Copyright Link Text', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'sanitize_text_field',
                            'transport'   => 'postMessage',
                        ),
                        'footer_copyright_link'      => array(
                            'title'       => esc_html__('Footer Copyright Link', 'icare'),
                            'description' => '',
                            'field_type'  => 'text',
                            'sanitize'    => 'esc_url_raw',
                            'transport'   => 'postMessage',
                        ),
                        'footer_social_or_menu'      => array(
                            'title'       => esc_html__('Show social Media Links or a Simple Menu in footer', 'icare'),
                            'description' => __('This menu can be set in the <a class="linkToControl" id="nav_menu_locations[footer-menu]" href="#">Menu Section</a>.', 'icare'),
                            'field_type'  => 'select',
                            'sanitize'    => 'sanitize_text_field',
                            'choices'     => array(
                                'social-links' => esc_html__('Social Links Menu', 'icare'),
                                'simple-links' => esc_html__('Simple Menu', 'icare'),
                                ''             => esc_html__('Blank', 'icare'),
                            ),
                        ),

                    ),
                ),
                'header_image'          => array(
                    'fields' => array(
                        // Header Options
                        'fixed_header'            => array(
                            'title'       => esc_html__('Fixed Header', 'icare'),
                            'description' => '',
                            'field_type'  => 'checkbox',
                            'sanitize'    => 'icare_sanitize_checkbox',
                        ),
                        'header_background_color' => array(
                            'title'       => esc_html__('Header Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'menu_color'              => array(
                            'title'       => esc_html__('Menu Text Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'menu_color_hover'        => array(
                            'title'       => esc_html__('Menu Text Color on Hover', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                        'menu_bg_color'           => array(
                            'title'       => esc_html__('Menu Background Color', 'icare'),
                            'description' => '',
                            'field_type'  => 'color',
                            'sanitize'    => 'sanitize_hex_color',
                        ),
                    ),
                ),
                'breadcrumb_title'      => array(
                    'title'       => esc_html__('Breadcrumbs & Title', 'icare'),
                    'description' => '',
                    'priority'    => 25,
                    'fields'      => array(
                        // Breadcrumb & Title Options
                        'crumb_and_title'        => array(
                            'field_type'  => 'select',
                            'title'       => esc_html__('Page Title Type', 'icare'),
                            'description' => esc_html__('Select pages title type.', 'icare'),
                            'choices'     => array(
                                'allow_both'  => 'Title Bar With Breadcrumbs',
                                'allow_title' => 'Title Bar Only',
                                'not_of_them' => 'Hide All',
                            ),
                            'sanitize'    => 'sanitize_text_field',
                        ),

                        'crumb_title_align'      => array(
                            'field_type'  => 'select',
                            'title'       => esc_html__('Page Title Align', 'icare'),
                            'description' => '',
                            'choices'     => array(
                                'left'   => 'Left',
                                'right'  => 'right',
                                'center' => 'center',
                            ),
                            'sanitize'    => 'sanitize_text_field',
                        ),
                        'crumb_title_align'      => array(
                            'field_type'  => 'select',
                            'title'       => esc_html__('Page Title Align', 'icare'),
                            'description' => '',
                            'choices'     => array(
                                'left'   => 'Left',
                                'right'  => 'right',
                                'center' => 'center',
                            ),
                            'sanitize'    => 'sanitize_text_field',
                        ),

                        'br_s_p_t'               => array(
                            'field_type'  => 'number',
                            'title'       => __('Breadcrumbs Section Padding Top', 'icare'),
                            'description' => '',
                            'sanitize'    => 'absint',
                        ),
                        'br_s_p_b'               => array(
                            'field_type'  => 'number',
                            'title'       => __('Breadcrumbs Section Padding Bottom', 'icare'),
                            'description' => '',
                            'sanitize'    => 'absint',
                        ),
                        'breadcrumbs_font_color' => array(
                            'field_type'  => 'color',
                            'title'       => __('Title bar Fonts color', 'icare'),
                            'description' => '',
                            'sanitize'    => 'sanitize_hex_color',
                        ),

                        'breadcrumbs_bg_image'   => array(
                            'field_type'  => 'image',
                            'title'       => __('Background Image', 'icare'),
                            'description' => '',
                            'sanitize'    => 'esc_url',
                        ),
                        'breadcrumbs_bg_video'   => array(
                            'field_type'  => 'text',
                            'title'       => __('Or enter background video URL', 'icare'),
                            'description' => '',
                            'sanitize'    => 'esc_url',
                        ),

                    ),
                ),
                'background_image'      => array(
                    'fields' => array(
                        //Footer Color options
                        'site_layout' => array(
                            'title'       => esc_html__('Site layout', 'icare'),
                            'description' => '',
                            'field_type'  => 'select',
                            'sanitize'    => 'sanitize_text_field',
                            'choices'     => array(
                                'boxed-layout pt-fourty pb-fourty pt-sm-zero' => esc_html__('Boxed Layout', 'icare'),
                                ''                                            => esc_html__('Full Width', 'icare'),
                            ),
                            'default'     => '',
                        ),
                    ),
                ),

            );

            foreach ($section_controls as $s_id => $section) {
                if (!in_array($s_id, array_keys($wp_customize->sections()))) {
                    $args = array(
                        'title'       => $section['title'],
                        'description' => $section['description'],
                        'priority'    => $section['priority'],
                    );
                    $args['panel'] = isset($section['panel']) ? $theme_slug . $section['panel'] : '';
                    $wp_customize->add_section($s_id, $args);
                }
                foreach ($section['fields'] as $c_id => $option) {
                    if ('image' == $option['field_type']) {
                        $wp_customize->add_setting(
                            // $id
                            $theme_slug . $c_id,
                            // parameters array
                            array(
                                'type'              => 'theme_mod',
                                'sanitize_callback' => $option['sanitize'],
                            )
                        );

                        $wp_customize->add_control(
                            new WP_Customize_Image_Control(
                                $wp_customize, $theme_slug . $c_id,
                                array(
                                    'label'    => $option['title'],
                                    'section'  => $s_id,
                                    'settings' => $theme_slug . $c_id,
                                )
                            )
                        );
                    } else if ('iCare_Customizer_Repeater' == $option['field_type']) {
                    $default = isset($option['default']) ? $option['default'] : '';
                    $wp_customize->add_setting(
                        // $c_id
                        $theme_slug . $c_id,
                        // parameters array
                        array(
                            'type'              => 'theme_mod',
                            'sanitize_callback' => $option['sanitize'],
                            'default'           => $default,
                        )
                    );
                    $args = array(
                        'label'    => $option['title'],
                        'section'  => $s_id,
                        'settings' => $theme_slug . $c_id,
                    );
                    foreach ($option['fields'] as $field => $val) {
                        $args[$field] = $val;
                    }
                    if (isset($option['active_callback'])) {
                        $args['active_callback'] = $option['active_callback'];
                    }
                    $wp_customize->add_control(
                        new iCare_Customizer_Repeater(
                            $wp_customize, $theme_slug . $c_id,
                            $args
                        )
                    );
                } else if ('divider' == $option['field_type']) {
                    $wp_customize->add_control(new Arbitrary_Icare_Control($wp_customize, $theme_slug . $c_id, array(
                        'section' => $s_id,
                        'type'    => 'divider',
                    )));
                } else if ('rawfield' == $option['field_type']) {
                    $wp_customize->add_control(new Arbitrary_Icare_Control($wp_customize, $theme_slug . $c_id, array(
                        'section' => $s_id,
                        'type'    => 'rawfield',
                    )));
                } else if ('radio-image' == $option['field_type']) {
                    $wp_customize->add_setting(
                        // $id
                        $theme_slug . $c_id,
                        // parameters array
                        array(
                            'type'              => 'theme_mod',
                            'sanitize_callback' => $option['sanitize'],
                        )
                    );
                    $wp_customize->add_control(new iCare_Custom_Radio_Image_Control($wp_customize, $theme_slug . $c_id, array(
                        'section' => $s_id,
                        'type'    => 'radio-image',
                        'choices' => $option['choices'],
                    )));
                } else {
                    //Normal Loop
                    $wp_customize->add_setting(
                        // $c_id
                        $theme_slug . $c_id,
                        // parameters array
                        array(
                            'type'              => 'theme_mod',
                            'transport'         => isset($option['transport']) ? 'postMessage' : 'refresh',
                            'sanitize_callback' => $option['sanitize'],
                        )
                    );

                    // Add setting control
                    $params = array(
                        'label'       => $option['title'],
                        'settings'    => $theme_slug . $c_id,
                        'type'        => $option['field_type'],
                        'description' => $option['description'],
                    );

                    if (isset($option['choices'])) {
                        $params['choices'] = $option['choices'];
                    }

                    if (isset($option['active_callback'])) {
                        $params['active_callback'] = $option['active_callback'];
                    }

                    if (isset($option['input_attrs'])) {
                        $params['input_attrs'] = $option['input_attrs'];
                    }

                    if ('header_image' == $s_id || 'colors' == $s_id) {
                        $params['section'] = $s_id;
                    } else {
                        $params['section'] = $s_id;
                    }
                    $wp_customize->add_control(
                        // $c_id
                        $theme_slug . $c_id,
                        $params
                    );

                }
            }
        }
        /* Add Partial Refresh */
        $partial_refresh = array(
            'cont_text'             => array(
                'selector' => '.cont-text',
            ),
            'hero_title'            => array(
                'selector' => '#h_title',
            ),
            'hero_desc'             => array(
                'selector' => '#h_subtitle',
            ),
            'calltoaction_title'    => array(
                'selector' => '#cta_title',
            ),
            'calltoaction_text'     => array(
                'selector' => '#cta_desc',
            ),
            'service_head'          => array(
                'selector' => '.service.title',
            ),
            'about_head'            => array(
                'selector' => '#aboutus_title',
            ),
            'about_desc'            => array(
                'selector' => '#aboutus_desc',
            ),
            'home_blog_title'       => array(
                'selector' => '#home_blog_title',
            ),
            'footer_copyright_text' => array(
                'selector' => '#icare-copyright-text',
            ),
        );

        foreach ($partial_refresh as $id => $opt) {
            $wp_customize->selective_refresh->add_partial($theme_slug . $id, array(
                'selector'        => $opt['selector'],
                'render_callback' => function () use ($theme_slug, $id) {

                    return get_theme_mod($theme_slug . $id);
                },
            ));
        }

        // Move background color setting alongside background image.
        $wp_customize->get_control('background_color')->section  = 'background_image';
        $wp_customize->get_control('background_color')->priority = 20;

        $wp_customize->get_control('header_textcolor')->section  = 'header_image';
        $wp_customize->get_control('header_textcolor')->priority = 11;

        $wp_customize->get_control('icare_site_layout')->priority = 9;

        // Change background image section title & priority.
        $wp_customize->get_section('background_image')->title       = esc_html__('Site Layout & Background', 'icare');
        $wp_customize->get_section('background_image')->description = esc_html__('Site Layout & Background Options', 'icare');
        $wp_customize->get_section('background_image')->priority    = 30;

        // Change header image section title & priority.
        $wp_customize->get_section('header_image')->title    = esc_html__('Header Options', 'icare');
        $wp_customize->get_section('header_image')->priority = 25;
        // Selective refresh.
        $wp_customize->get_setting('blogname')->transport         = 'postMessage';
        $wp_customize->get_setting('blogdescription')->transport  = 'postMessage';
        $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

        $wp_customize->selective_refresh->add_partial('custom_logo', array(
            'selector'        => '.icaremenu-brand',
            'render_callback' => array($this, 'icare_get_site_logo'),
        ));

        $wp_customize->selective_refresh->add_partial('blogname', array(
            'selector'        => '.site-title',
            'render_callback' => array($this, 'icare_get_site_name'),
        ));

        $wp_customize->selective_refresh->add_partial('blogdescription', array(
            'selector'        => '.site-description',
            'render_callback' => array($this, 'icare_get_site_description'),
        ));

        // extra section control
        /**
         * Filter number of front page sections in Twenty Seventeen.
         *
         * @since Twenty Seventeen 1.0
         *
         * @param int $num_sections Number of front page sections.
         */

        // home page re-order
        $wp_customize->add_section($theme_slug . 'home_page', array(
            'title'       => __('Home Page Re-order', 'icare'),
            'description' => __('Here you can re-order your Home Page Section', 'icare'),
            'priority'    => 130, // Before Additional CSS.
        ));

        $wp_customize->add_setting(
            // $id
            $theme_slug . 'home_reorder',
            // parameters array
            array(
                'type'              => 'theme_mod',
                'sanitize_callback' => 'icare_sanitize_json_string',
            )
        );
        $wp_customize->add_control(new iCare_Custom_sortable_Control($wp_customize, $theme_slug . 'home_reorder', array(
            'section' => $theme_slug . 'home_page',
            'type'    => 'home-sortable',
            'choices' => array(
                'home-service'      => __('Home Service', 'icare'),
                'home-about_1'      => __('Home Extra 1', 'icare'),
                'home-about_2'      => __('Home Extra 2', 'icare'),
                'home-posts'        => __('Home posts', 'icare'),
                'home-calltoaction' => __('Home CTA', 'icare'),
            ),
        )));

    }
    /**
     * Get all of the iCare theme mods.
     *
     * @return array $icare_theme_mods The iCare Theme Mods.
     */
    public static function get_icare_theme_mods()
    {
        $icare_theme_mods = array(
            'topbar_bg_color'         => get_theme_mod('icare_topbar_bg_color'),
            'topbar_link_color'       => get_theme_mod('icare_topbar_link_color'),
            'background_color'        => get_theme_mod('background_color'),
            'fixed_header'            => get_theme_mod('icare_fixed_header'),
            'header_background_color' => get_theme_mod('icare_header_background_color'),
            'breadcrumbs_font_color' => get_theme_mod('icare_breadcrumbs_font_color'),
            'br_s_p_t' => get_theme_mod('icare_br_s_p_t'),
            'br_s_p_b' => get_theme_mod('icare_br_s_p_b'),
            'menu_color'              => get_theme_mod('icare_menu_color'),
            'menu_color_hover'        => get_theme_mod('icare_menu_color_hover'),
            'menu_bg_color'           => get_theme_mod('icare_menu_bg_color'),
            'home_blog_color'         => get_theme_mod('icare_home_blog_color'),
            'service_color'           => get_theme_mod('icare_service_color'),
            'about_color1'            => get_theme_mod('icare_about_color1'),
            'about_head1_color'       => get_theme_mod('icare_about_head1_color'),
            'about_desc1_color'       => get_theme_mod('icare_about_desc1_color'),
            'about_color2'            => get_theme_mod('icare_about_color2'),
            'about_head2_color'       => get_theme_mod('icare_about_head2_color'),
            'about_desc2_color'       => get_theme_mod('icare_about_desc2_color'),
            'footer_background_color' => get_theme_mod('icare_footer_background_color'),
            'footer_link_color'       => get_theme_mod('icare_footer_link_color'),
            'footer_heading_color'    => get_theme_mod('icare_footer_heading_color'),
            'footer_text_color'       => get_theme_mod('icare_footer_text_color'),
            'cta_bg_color'            => get_theme_mod('icare_cta_bg_color'),
            'cta_font_color'          => get_theme_mod('icare_cta_font_color'),
        );

        return apply_filters('icare_theme_mods', $icare_theme_mods);
    }

    /**
     * Get Customizer css.
     *
     * @see get_icare_theme_mods()
     * @return array $styles the css
     */
    public function icare_get_css()
    {
        $icare_theme_mods = $this->get_icare_theme_mods();
        $brighten_factor  = apply_filters('icare_brighten_factor', 25);
        $darken_factor    = apply_filters('icare_darken_factor', -25);

        $styles = '
            .top-header.icare-theme-bg-colored{
                background-color:' . $icare_theme_mods['topbar_bg_color'] . '!important;
            }
            .top-header .styled-icons.icon-dark a,.social-links a{
                background-color:' . icare_adjust_color_brightness($icare_theme_mods['topbar_bg_color'], 25) . ';
            }
            .top-header .icon-theme-colored.icon-dark a:hover{
                background-color:' . icare_adjust_color_brightness($icare_theme_mods['topbar_bg_color'], 35) . '
            }
            .topbar-btn.icare-text-colored{color:' . $icare_theme_mods['topbar_bg_color'] . '!important;}
            #header .links > ul > li > a, #header .links > ul > li .wrap_custom_block > a,.drop-icon{
                color:' . $icare_theme_mods['topbar_link_color'] . ';
            }
            .header_nav{
                background-color:' . $icare_theme_mods['header_background_color'] . ';
            }
            #primary-menu > li > a{
                color:' . $icare_theme_mods['menu_color'] . '
            }
            
            .brcmb-container h2.title,.brcmb-container li, .brcmb-container li a{color:'.$icare_theme_mods['breadcrumbs_font_color'].';}
            .brcmb-container{padding-top:'.$icare_theme_mods['br_s_p_t'].'px !important;padding-bottom:'.$icare_theme_mods['br_s_p_b'].'px !important;}
            #cssmenu ul li:hover > a, #cssmenu ul li.active > a,.slicknav_nav>li.active>a, .slicknav_nav>li:hover>a, .slicknav_nav ul.dropdown li:hover>a{
                background:' . $icare_theme_mods['menu_bg_color'] . '!important;
                color:' . $icare_theme_mods['menu_color_hover'] . '!important;
            }
            #services{background:' . $icare_theme_mods['service_color'] . ';}
            #about1{background-color:' . $icare_theme_mods['about_color1'] . ';}
            #aboutus_title1{color:' . $icare_theme_mods['about_head1_color'] . ';}
            #aboutus_desc1{color:' . $icare_theme_mods['about_desc1_color'] . '!important;}
            #aboutus_title2{color:' . $icare_theme_mods['about_head2_color'] . ';}
            #aboutus_desc2{color:' . $icare_theme_mods['about_desc2_color'] . '!important;}
            #about2{background-color:' . $icare_theme_mods['about_color2'] . ';}
            #about1.layer-overlay.color-overlay::before{background-color:' . icare_hex2rgba($icare_theme_mods['about_color1'], 0.4) . ';}
            #about2.layer-overlay.color-overlay::before{background-color:' . icare_hex2rgba($icare_theme_mods['about_color2'], 0.4) . ';}
            #blog{background:' . $icare_theme_mods['home_blog_color'] . ';}
            .icare-footer,.icare-footer .styled-icons.icon-dark a{background-color:' . $icare_theme_mods['footer_background_color'] . ';}
            .icare-footer, .icare-footer caption{ color:' . $icare_theme_mods['footer_text_color'] . ';}
            .icare-footer a { color:' . $icare_theme_mods['footer_link_color'] . ';}
             .icare-footer td#today{ background-color:' . $icare_theme_mods['footer_link_color'] . ';}
            .icare-footer .icare-widget.dark .icare-widget-title { color:' . $icare_theme_mods['footer_heading_color'] . ';}
            .icare-footer-bottom{background:' . icare_adjust_color_brightness($icare_theme_mods['footer_background_color'], 25) . '}

            #cta{background-color:' . $icare_theme_mods['cta_bg_color'] . ' !important}
            #cta,#cta a,h3#cta_title{color:' . $icare_theme_mods['cta_font_color'] . ' !important}';

        return apply_filters('icare_customizer_css', $styles);
    }

    /**
     * Assign iCare styles to individual theme mods.
     *
     * @return void
     */
    public function icare_set_style_theme_mods()
    {
        set_theme_mod('icare_styles', $this->icare_get_css());
    }

    /**
     * Add CSS in <head> for styles handled by the theme customizer
     * If the Customizer is active pull in the raw css. Otherwise pull in the prepared theme_mods if they exist.
     *
     * @since 1.0.0
     * @return void
     */
    public function icare_add_customizer_css()
    {
        $icare_styles = get_theme_mod('icare_styles');

        if (is_customize_preview() || (defined('WP_DEBUG') && true === WP_DEBUG) || (false === $icare_styles && false === $icare_woocommerce_styles)) {
            wp_add_inline_style('icare-style', $this->icare_get_css());
        } else {
            wp_add_inline_style('icare-style', get_theme_mod('icare_styles'));
        }
    }

    /**
     * Add CSS for custom controls
     *
     * This function incorporates CSS from the Kirki Customizer Framework
     *
     * The Kirki Customizer Framework, Copyright Aristeides Stathopoulos (@aristath),
     * is licensed under the terms of the GNU GPL, Version 2 (or later)
     *
     * @link https://github.com/reduxframework/kirki/
     * @since  1.5.0
     */
    public function icare_customizer_custom_control_css()
    {
        ?>
            <style>
            .customize-control-radio-image .image.ui-buttonset input[type=radio] {
                height: auto;
            }

            .customize-control-radio-image .image.ui-buttonset label {
                display: inline-block;
                width: 18%;
                padding: 1%;
                box-sizing: border-box;
            }

            .customize-control-radio-image .image.ui-buttonset label.ui-state-active {
                background: none;
            }

            .customize-control-radio-image .customize-control-radio-buttonset label {
                background: #f7f7f7;
                line-height: 35px;
            }

            .customize-control-radio-image label img {
                opacity: 0.5;
            }

            #customize-controls .customize-control-radio-image label img {
                height: auto;
            }

            .customize-control-radio-image label.ui-state-active img {
                background: #dedede;
                opacity: 1;
            }

            .customize-control-radio-image label.ui-state-hover img {
                opacity: 1;
                box-shadow: 0 0 0 3px #f6f6f6;
            }
            </style>
            <?php
}

    /**
     * Get site logo.
     *
     * @since 2.1.5
     * @return string
     */
    public function icare_get_site_logo()
    {
        return icare_site_title_or_logo(false);
    }

    /**
     * Get site name.
     *
     * @since 2.1.5
     * @return string
     */
    public function icare_get_site_name()
    {
        return get_bloginfo('name', 'display');
    }

    /**
     * Get site description.
     *
     * @since 2.1.5
     * @return string
     */
    public function icare_get_site_description()
    {
        return get_bloginfo('description', 'display');
    }

}
endif;
add_action('customize_controls_enqueue_scripts', 'icare_enqueue_control_assets');
function icare_enqueue_control_assets()
{

    wp_enqueue_script('icare-custom-controls', get_template_directory_uri() . '/assets/js/icare-custom-controls.js', array('jquery', 'customize-controls'), '20130508', true);
}
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function icare_customize_preview_js()
{
    wp_enqueue_script('icare_customizer', get_template_directory_uri() . '/js/icare-customizer.js', array('customize-preview'), '20130508', true);
}
add_action('customize_preview_init', 'icare_customize_preview_js');

return new iCare_Customizer();